aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/StudioModuleBase.cs
diff options
context:
space:
mode:
Diffstat (limited to 'Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/StudioModuleBase.cs')
-rw-r--r--Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/StudioModuleBase.cs4
1 files changed, 2 insertions, 2 deletions
diff --git a/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/StudioModuleBase.cs b/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/StudioModuleBase.cs
index 11da53c6c..68fe5b95e 100644
--- a/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/StudioModuleBase.cs
+++ b/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/StudioModuleBase.cs
@@ -41,9 +41,9 @@ namespace Tango.MachineStudio.Common
public abstract BitmapSource Image { get; }
/// <summary>
/// Gets the module entry point view.
/// </summary>
- public abstract FrameworkElement MainView { get; }
+ public abstract Type MainViewType { get; }
/// <summary>
/// Gets the permission required to see and load this module.
@@ -41,9 +41,9 @@ namespace Tango.MachineStudio.Common
public abstract BitmapSource Image { get; }
/// <summary>
- /// Gets the module entry point view.
+ /// Gets the module entry point view type.
/// </summary>